@@ -61,11 +61,11 @@ def load_responses_fixtures(path) -> None:
         matchers: List[Any] = []
         if fixture.get('match_json_params'):
             matchers.append(
-                responses.json_params_matcher(fixture['match_json_params'])
+                responses.json_params_matcher(fixture['match_json_params'])  # type: ignore
             )
         if fixture.get('match_urlencoded_params'):
             matchers.append(
-                responses.urlencoded_params_matcher(
+                responses.urlencoded_params_matcher(  # type: ignore
                     fixture['match_urlencoded_params']
                 )
             )
